==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/TextFile.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) A text file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.452Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.TextFile")
public class TextFile extends io.github.cdklabs.projen.FileBase {

    protected TextFile(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TextFile(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (experimental) Defines a text file.
     * <p>
     * @param project The project. This parameter is required.
     * @param filePath File path. This parameter is required.
     * @param options Options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TextFile(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String filePath, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.TextFileOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(filePath, "filePath is required"), options });
    }

    /**
     * (experimental) Defines a text file.
     * <p>
     * @param project The project. This parameter is required.
     * @param filePath File path. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TextFile(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String filePath) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(filePath, "filePath is required") });
    }

    /**
     * (experimental) Adds a line to the text file.
     * <p>
     * @param line the line to add (can use tokens). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addLine(final @org.jetbrains.annotations.NotNull java.lang.String line) {
        software.amazon.jsii.Kernel.call(this, "addLine", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(line, "line is required") });
    }

    /**
     * (experimental) Implemented by derived classes and returns the contents of the file to emit.
     * <p>
     * @param _ This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    protected @org.jetbrains.annotations.Nullable java.lang.String synthesizeContent(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IResolver _) {
        return software.amazon.jsii.Kernel.call(this, "synthesizeContent", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(_, "_ is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.TextFile}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.TextFile> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project The project. This parameter is required.
         * @param filePath File path. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            return new Builder(project, filePath);
        }

        private final io.github.cdklabs.projen.Project project;
        private final java.lang.String filePath;
        private io.github.cdklabs.projen.TextFileOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            this.project = project;
            this.filePath = filePath;
        }

        /**
         * (experimental) Indicates whether this file should be committed to git or ignored.
         * <p>
         * By
         * default, all generated files are committed and anti-tamper is used to
         * protect against manual modifications.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param committed Indicates whether this file should be committed to git or ignored. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder committed(final java.lang.Boolean committed) {
            this.options().committed(committed);
            return this;
        }

        /**
         * (experimental) Update the project's .gitignore file.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param editGitignore Update the project's .gitignore file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder editGitignore(final java.lang.Boolean editGitignore) {
            this.options().editGitignore(editGitignore);
            return this;
        }

        /**
         * (experimental) Whether the generated file should be marked as executable.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param executable Whether the generated file should be marked as executable. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder executable(final java.lang.Boolean executable) {
            this.options().executable(executable);
            return this;
        }

        /**
         * (experimental) Whether the generated file should be readonly.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param readonly Whether the generated file should be readonly. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder readonly(final java.lang.Boolean readonly) {
            this.options().readonly(readonly);
            return this;
        }

        /**
         * (experimental) The contents of the text file.
         * <p>
         * You can use <code>addLine()</code> to append lines.
         * <p>
         * Default: [] empty file
         * <p>
         * @return {@code this}
         * @param lines The contents of the text file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lines(final java.util.List<java.lang.String> lines) {
            this.options().lines(lines);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.TextFile}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.TextFile build() {
            return new io.github.cdklabs.projen.TextFile(
                this.project,
                this.filePath,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.TextFileOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.TextFileOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/TextFile.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) A text file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.160Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.TextFile")
public class TextFile extends io.github.cdklabs.projen.FileBase {

    protected TextFile(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TextFile(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (experimental) Defines a text file.
     * <p>
     * @param scope This parameter is required.
     * @param filePath File path. This parameter is required.
     * @param options Options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TextFile(final @org.jetbrains.annotations.NotNull software.constructs.IConstruct scope, final @org.jetbrains.annotations.NotNull java.lang.String filePath, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.TextFileOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(filePath, "filePath is required"), options });
    }

    /**
     * (experimental) Defines a text file.
     * <p>
     * @param scope This parameter is required.
     * @param filePath File path. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TextFile(final @org.jetbrains.annotations.NotNull software.constructs.IConstruct scope, final @org.jetbrains.annotations.NotNull java.lang.String filePath) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(filePath, "filePath is required") });
    }

    /**
     * (experimental) Adds a line to the text file.
     * <p>
     * @param line the line to add (can use tokens). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addLine(final @org.jetbrains.annotations.NotNull java.lang.String line) {
        software.amazon.jsii.Kernel.call(this, "addLine", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(line, "line is required") });
    }

    /**
     * (experimental) Implemented by derived classes and returns the contents of the file to emit.
     * <p>
     * @param _ This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    protected @org.jetbrains.annotations.Nullable java.lang.String synthesizeContent(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IResolver __) {
        return software.amazon.jsii.Kernel.call(this, "synthesizeContent", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(__, "__ is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.TextFile}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.TextFile> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param filePath File path. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.IConstruct scope, final java.lang.String filePath) {
            return new Builder(scope, filePath);
        }

        private final software.constructs.IConstruct scope;
        private final java.lang.String filePath;
        private io.github.cdklabs.projen.TextFileOptions.Builder options;

        private Builder(final software.constructs.IConstruct scope, final java.lang.String filePath) {
            this.scope = scope;
            this.filePath = filePath;
        }

        /**
         * (experimental) Indicates whether this file should be committed to git or ignored.
         * <p>
         * By
         * default, all generated files are committed and anti-tamper is used to
         * protect against manual modifications.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param committed Indicates whether this file should be committed to git or ignored. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder committed(final java.lang.Boolean committed) {
            this.options().committed(committed);
            return this;
        }

        /**
         * (experimental) Update the project's .gitignore file.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param editGitignore Update the project's .gitignore file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder editGitignore(final java.lang.Boolean editGitignore) {
            this.options().editGitignore(editGitignore);
            return this;
        }

        /**
         * (experimental) Whether the generated file should be marked as executable.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param executable Whether the generated file should be marked as executable. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder executable(final java.lang.Boolean executable) {
            this.options().executable(executable);
            return this;
        }

        /**
         * (experimental) Adds the projen marker to the file.
         * <p>
         * Default: - marker will be included as long as the project is not ejected
         * <p>
         * @return {@code this}
         * @param marker Adds the projen marker to the file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder marker(final java.lang.Boolean marker) {
            this.options().marker(marker);
            return this;
        }

        /**
         * (experimental) Whether the generated file should be readonly.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param readonly Whether the generated file should be readonly. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder readonly(final java.lang.Boolean readonly) {
            this.options().readonly(readonly);
            return this;
        }

        /**
         * (experimental) The contents of the text file.
         * <p>
         * You can use <code>addLine()</code> to append lines.
         * <p>
         * Default: [] empty file
         * <p>
         * @return {@code this}
         * @param lines The contents of the text file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lines(final java.util.List<java.lang.String> lines) {
            this.options().lines(lines);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.TextFile}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.TextFile build() {
            return new io.github.cdklabs.projen.TextFile(
                this.scope,
                this.filePath,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.TextFileOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.TextFileOptions.Builder();
            }
            return this.options;
        }
    }
}
